Module chip

Module chip 

Re-exports

pub use communication::chip_comms::axi_translate;
pub use communication::chip_comms::ArcIf;
pub use communication::chip_comms::AxiData;
pub use communication::chip_comms::AxiError;
pub use communication::chip_comms::ChipComms;
pub use communication::chip_comms::MemorySlice;
pub use communication::chip_comms::MemorySlices;
pub use communication::chip_interface::ChipInterface;
pub use communication::chip_interface::NocInterface;
pub use wh_ubb::ubb_wait_for_driver_load;
pub use wh_ubb::wh_ubb_ipmi_reset;

Modules

communication
eth_addr
spirom_tables
wh_ubb

Structs

ArcMsgOptions
Arc message interface
Blackhole
Chip
A wrapper around a chip that implements ChipImpl. This allows us to create and use chips without knowing their type, but we can still downcast to the concrete type if we need to.
ChipDetectState
ComponentStatusInfo
A generic structure which contains the status information for each component. There is enough information here to determine the
InitStatus
NeighbouringChip
Telemetry
Wormhole
Implementation of the interface for a Wormhole both the local and remote Wormhole chips are represented by this struct

Enums

ArcMsg
ArcMsgOk
CallReason
ChipInitResult
CommsStatus
InitError
MessageError

Traits

ChipImpl
Defines common functionality for all chips. This is a convenience interface that allows chip type agnostic code to be written.
HlComms
Convenience trait for high-level communication with an arbitrary chip.
HlCommsInterface
These functions can’ be stored as a fat pointer so they are split out here. There is a blanket implementation for all types that implement HlComms.

Functions

wait_for_init
This function will wait for the chip to be initialized. It will return Ok(true) if the chip initialized successfully. It will return Ok(false) if the chip failed to initialize, but we can continue running. - This is only possible if allow_failure is true. An Err(..) will be returned if the chip failed to initialize and we cannot continue running the chip detection sequence. - In the case that allow_failure is false, Ok(true) will be returned as an error.