Module chip_interface

Module chip_interface 

Structs

NocInterface

Traits

ChipInterface
This trait is used to abstract the interface to the lowest level chip communication primitives. These primitives are defined to be a chip resource which requires exclusive access to safely use.