pub struct InitStatus {
pub comms_status: CommsStatus,
pub dram_status: ComponentStatusInfo<Infallible, DramInitError>,
pub cpu_status: ComponentStatusInfo<Infallible, CpuInitError>,
pub arc_status: ComponentStatusInfo<Infallible, ArcInitError>,
pub eth_status: ComponentStatusInfo<EthernetPartialInitError, EthernetInitError>,
pub init_options: InitOptions,
pub unknown_state: bool,
}Fields
comms_status: CommsStatusdram_status: ComponentStatusInfo<Infallible, DramInitError>cpu_status: ComponentStatusInfo<Infallible, CpuInitError>arc_status: ComponentStatusInfo<Infallible, ArcInitError>eth_status: ComponentStatusInfo<EthernetPartialInitError, EthernetInitError>init_options: InitOptionsunknown_state: boolWe cannot communicate with the chip prior to the initialization process. Therefore we start with the chip in an unknown state (all status is marked as not present).
Implementations
Sourceimpl InitStatus
impl InitStatus
pub fn new_unknown() -> Self
pub fn can_communicate(&self) -> bool
pub fn is_waiting(&self) -> bool
pub fn init_complete(&self) -> bool
pub fn has_error(&self) -> bool