Module chip_interface
luwen_
api
0.8.5
Module chip_
interface
Module Items
Structs
Traits
In luwen_
api::
chip::
communication
luwen_api
::
chip
::
communication
Module
chip_
interface
Structs

NocInterface
Traits

Chip
Interface
This trait is used to abstract the interface to the lowest level chip communication primitives. These primitives are defined to be a chip resource which requires exclusive access to safely use.