pub fn wait_for_init<E>(
chip: &mut impl ChipImpl,
callback: &mut impl FnMut(ChipDetectState<'_>) -> Result<(), E>,
allow_failure: bool,
noc_safe: bool,
) -> Result<InitStatus, InitError<E>>Expand description
This function will wait for the chip to be initialized. It will return Ok(true) if the chip initialized successfully. It will return Ok(false) if the chip failed to initialize, but we can continue running. - This is only possible if allow_failure is true. An Err(..) will be returned if the chip failed to initialize and we cannot continue running the chip detection sequence. - In the case that allow_failure is false, Ok(true) will be returned as an error.
This component makes a callback available which allows the init status to be updated if there is someone/something monitoring the init progress. The initial/driving purpose of this is to track the progress on the command line.